.. currentmodule:: sardana.macroserver.macros

.. _macroserver-standard-macro-catalog:

:mod:`~sardana.macroserver.macros`
===================================

.. automodule:: sardana.macroserver.macros

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 5

    * :class:`~sardana.macroserver.macros.standard.wa`
    * :class:`~sardana.macroserver.macros.standard.wm`
    * :class:`~sardana.macroserver.macros.standard.pwa`
    * :class:`~sardana.macroserver.macros.standard.pwm`
    * :class:`~sardana.macroserver.macros.standard.set_lim`
    * :class:`~sardana.macroserver.macros.standard.set_lm`
    * :class:`~sardana.macroserver.macros.standard.set_pos`
    * :class:`~sardana.macroserver.macros.standard.mv`
    * :class:`~sardana.macroserver.macros.standard.umv`
    * :class:`~sardana.macroserver.macros.standard.mvr`
    * :class:`~sardana.macroserver.macros.standard.umvr`
    * :class:`~sardana.macroserver.macros.standard.ct`
    * :class:`~sardana.macroserver.macros.standard.uct`
    * :class:`~sardana.macroserver.macros.standard.settimer`

    * :class:`~sardana.macroserver.macros.env.lsenv`
    * :class:`~sardana.macroserver.macros.env.senv`
    * :class:`~sardana.macroserver.macros.env.usenv`
    * :class:`~sardana.macroserver.macros.env.dumpenv`

    * :class:`~sardana.macroserver.macros.lists.lsa`
    * :class:`~sardana.macroserver.macros.lists.lsm`
    * :class:`~sardana.macroserver.macros.lists.lspm`
    * :class:`~sardana.macroserver.macros.lists.lsexp`
    * :class:`~sardana.macroserver.macros.lists.lsior`
    * :class:`~sardana.macroserver.macros.lists.lsmeas`
    * :class:`~sardana.macroserver.macros.lists.lsct`
    * :class:`~sardana.macroserver.macros.lists.ls0d`
    * :class:`~sardana.macroserver.macros.lists.ls1d`
    * :class:`~sardana.macroserver.macros.lists.ls2d`
    * :class:`~sardana.macroserver.macros.lists.lspc`
    * :class:`~sardana.macroserver.macros.lists.lsctrl`
    * :class:`~sardana.macroserver.macros.lists.lspc`
    * :class:`~sardana.macroserver.macros.lists.lsi`
    * :class:`~sardana.macroserver.macros.lists.lsctrllib`

    * :class:`~sardana.macroserver.macros.expert.lsmac`
    * :class:`~sardana.macroserver.macros.expert.defmeas`
    * :class:`~sardana.macroserver.macros.expert.udefmeas`
    * :class:`~sardana.macroserver.macros.expert.defelem`
    * :class:`~sardana.macroserver.macros.expert.udefelem`
    * :class:`~sardana.macroserver.macros.expert.defctrl`
    * :class:`~sardana.macroserver.macros.expert.udefctrl`
    * :class:`~sardana.macroserver.macros.expert.prdef`
    * :class:`~sardana.macroserver.macros.expert.relmac`
    * :class:`~sardana.macroserver.macros.expert.relmaclib`
    
    * :class:`~sardana.macroserver.macros.scan.ascan`
    * :class:`~sardana.macroserver.macros.scan.a2scan`
    * :class:`~sardana.macroserver.macros.scan.a3scan`
    * :class:`~sardana.macroserver.macros.scan.a4scan`
    * :class:`~sardana.macroserver.macros.scan.amultiscan`
    * :class:`~sardana.macroserver.macros.scan.dscan`
    * :class:`~sardana.macroserver.macros.scan.d2scan`
    * :class:`~sardana.macroserver.macros.scan.d3scan`
    * :class:`~sardana.macroserver.macros.scan.d4scan`
    * :class:`~sardana.macroserver.macros.scan.dmultiscan`
    * :class:`~sardana.macroserver.macros.scan.mesh`
    * :class:`~sardana.macroserver.macros.scan.fscan`
    * :class:`~sardana.macroserver.macros.scan.scanhist`


wa
---

.. autoclass:: sardana.macroserver.macros.standard.wa
    :members:

    
wm
---

.. autoclass:: sardana.macroserver.macros.standard.wm
    :members:

    
pwa
---------

.. autoclass:: sardana.macroserver.macros.standard.pwa
    :members:

    
pwm
---------

.. autoclass:: sardana.macroserver.macros.standard.pwm
    :members:

    
set_lim
---------

.. autoclass:: sardana.macroserver.macros.standard.set_lim
    :members:

    
set_lm
---------

.. autoclass:: sardana.macroserver.macros.standard.set_lm
    :members:

    
set_pos
---------

.. autoclass:: sardana.macroserver.macros.standard.set_pos
    :members:

    
mv
---------

.. autoclass:: sardana.macroserver.macros.standard.mv
    :members:


umv
---------

.. autoclass:: sardana.macroserver.macros.standard.umv
    :members:


mvr
---------

.. autoclass:: sardana.macroserver.macros.standard.mvr
    :members:


umvr
---------

.. autoclass:: sardana.macroserver.macros.standard.umvr
    :members:


ct
---------

.. autoclass:: sardana.macroserver.macros.standard.ct
    :members:


uct
---------

.. autoclass:: sardana.macroserver.macros.standard.uct
    :members:


settimer
---------

.. autoclass:: sardana.macroserver.macros.standard.settimer
    :members:


lsenv
---------

.. autoclass:: sardana.macroserver.macros.env.lsenv
    :members:


senv
---------

.. autoclass:: sardana.macroserver.macros.env.senv
    :members:


usenv
---------

.. autoclass:: sardana.macroserver.macros.env.usenv
    :members:


dumpenv
---------

.. autoclass:: sardana.macroserver.macros.env.dumpenv
    :members:


lsa
---------

.. autoclass:: sardana.macroserver.macros.lists.lsa
    :members:


lsm
---------

.. autoclass:: sardana.macroserver.macros.lists.lsm
    :members:


lspm
---------

.. autoclass:: sardana.macroserver.macros.lists.lspm
    :members:


lsexp
---------

.. autoclass:: sardana.macroserver.macros.lists.lsexp
    :members:


lsior
---------

.. autoclass:: sardana.macroserver.macros.lists.lsior
    :members:


lsmeas
---------

.. autoclass:: sardana.macroserver.macros.lists.lsmeas
    :members:


lsct
---------

.. autoclass:: sardana.macroserver.macros.lists.lsct
    :members:


ls0d
---------

.. autoclass:: sardana.macroserver.macros.lists.ls0d
    :members:


ls1d
---------

.. autoclass:: sardana.macroserver.macros.lists.ls1d
    :members:


ls2d
---------

.. autoclass:: sardana.macroserver.macros.lists.ls2d
    :members:


lspc
---------

.. autoclass:: sardana.macroserver.macros.lists.lspc
    :members:


lsctrl
---------

.. autoclass:: sardana.macroserver.macros.lists.lsctrl
    :members:


lsi
---------

.. autoclass:: sardana.macroserver.macros.lists.lsi
    :members:


lsctrllib
---------

.. autoclass:: sardana.macroserver.macros.lists.lsctrllib
    :members:


    
ascan
-----

.. autoclass:: sardana.macroserver.macros.scan.ascan
    :members:



a2scan
------

.. autoclass:: sardana.macroserver.macros.scan.a2scan
    :members:


a3scan
------

.. autoclass:: sardana.macroserver.macros.scan.a3scan
    :members:


a4scan
------

.. autoclass:: sardana.macroserver.macros.scan.a4scan
    :members:


amultiscan
----------

.. autoclass:: sardana.macroserver.macros.scan.amultiscan
    :members:


dscan
-----

.. autoclass:: sardana.macroserver.macros.scan.dscan
    :members:



d2scan
------

.. autoclass:: sardana.macroserver.macros.scan.d2scan
    :members:


d3scan
------

.. autoclass:: sardana.macroserver.macros.scan.d3scan
    :members:


d4scan
------

.. autoclass:: sardana.macroserver.macros.scan.d4scan
    :members:


dmultiscan
----------

.. autoclass:: sardana.macroserver.macros.scan.dmultiscan
    :members:


mesh
-----

.. autoclass:: sardana.macroserver.macros.scan.mesh
    :members:


fscan
-----

.. autoclass:: sardana.macroserver.macros.scan.fscan
    :members:


scanhist
--------

.. autoclass:: sardana.macroserver.macros.scan.scanhist
    :members:
